@@ -3,8 +3,8 @@ from django_filters.rest_framework import DjangoFilterBackend
 
 from ..utils.page import CargoPageSetPagination, YzPageSetPagination
 from ..utils.yzModelViewSet import FalseDeleteModelViewSet
-from data_apps.tlms_wms_public_table import models
-from data_apps.tlms_wms_public_table import serializer
+from . import models
+from . import serializer
 from rest_framework import filters
 
 
